@@ -420,11 +420,12 @@ class Client:
 
     async def isAllowed(self, vin):
         perms = await self.getPermissions(vin)
+        print(perms)
         allowed = False
         reason = ""
         if perms["userIsActive"] and perms["userRoleStatus"] == "ENABLED":
             service_status = await self._connection.get(
-                f"https://api.porsche.com/core/api/v3/de/de_DE/services?{vin}"
+                f"https://api.porsche.com/core/api/v4/de/de_DE/services?{vin}"
             )
             print(service_status)
             reason = service_status.get(
@@ -433,6 +434,7 @@ class Client:
             mydata = await self._connection.get(
                 f"https://api.porsche.com/profiles/mydata?country={self.country}"
             )
+            _LOGGER.debug(mydata)
             for vehicle in mydata["vehicles"]:
                 print(vehicle)
                 if vehicle["vin"] == vin:
